Crate paystack

source ·

Structs

  • This is the struct that allows you to authenticate to the PayStack API. It contains the API key which allows you to interact with the API.
  • Wrapper type which contains a failed request’s status code and body
  • This struct is used to create a transaction body for creating a transaction using the Paystack API.
  • This struct mirrors the response of the Paystack transaction initalization response.

Enums

Type Definitions