Module subaccount

Module subaccount 

Subaccounts

The Subaccounts API allows you to create and manage subaccounts on your integration. Subaccounts can be used to split payment between two accounts (your main account and a subaccount).

Structs

SubaccountEndpoints
A struct to hold all functions in the subaccount API route