pub struct SubaccountEndpoints<T: HttpClient + Default> { /* private fields */ }Expand description
A struct to hold all functions in the subaccount API route
Implementations
Sourceimpl<T: HttpClient + Default> SubaccountEndpoints<T>
impl<T: HttpClient + Default> SubaccountEndpoints<T>
Sourcepub async fn create_subaccount(
&self,
subaccount_request: CreateSubaccountRequest,
) -> PaystackResult<SubaccountsResponseData>
pub async fn create_subaccount( &self, subaccount_request: CreateSubaccountRequest, ) -> PaystackResult<SubaccountsResponseData>
Sourcepub async fn list_subaccounts(
&self,
per_page: Option<u32>,
page: Option<u32>,
) -> PaystackResult<Vec<SubaccountsResponseData>>
pub async fn list_subaccounts( &self, per_page: Option<u32>, page: Option<u32>, ) -> PaystackResult<Vec<SubaccountsResponseData>>
Sourcepub async fn fetch_subaccount(
&self,
id_or_code: String,
) -> PaystackResult<SubaccountsResponseData>
pub async fn fetch_subaccount( &self, id_or_code: String, ) -> PaystackResult<SubaccountsResponseData>
Sourcepub async fn update_subaccount(
&self,
id_or_code: String,
update_request: CreateSubaccountRequest,
) -> PaystackResult<SubaccountsResponseData>
pub async fn update_subaccount( &self, id_or_code: String, update_request: CreateSubaccountRequest, ) -> PaystackResult<SubaccountsResponseData>
Update a subaccount details in your integration
Arguments
id_or_code- Subaccount’s ID or codeupdate_request- The request data to update the subaccount. It should be created with theCreateSubaccountRequestBuilderstruct.
Returns
A Result containing the updated subaccount response data or an error