Module transaction

Module transaction 

Transactions

The Transaction route allows to create and manage payments on your integration.

Structs

TransactionEndpoints
A struct to hold all the functions of the transaction API endpoint