Module plans_models

Module plans_models 

Plans Models

This file contains the models and options for the Plans endpoint of the Paystack API

Structs

PlanRequest
Request body to create a plan on your integration. Should be created via PlanRequestBuilder
PlanRequestBuilder
Builder for PlanRequest.
PlanResponseData
This struct represents the data of the create plan response.
PlanUpdateRequest
Request body to update a plan on your integration. Should be created via PlanUpdateRequestBuilder
PlanUpdateRequestBuilder
Builder for PlanUpdateRequest.

Enums

Interval
Options for the different payment intervals for plans supported by the paystack API.
PlanRequestBuilderError
Error type for PlanRequestBuilder
PlanStatus
PlanUpdateRequestBuilderError
Error type for PlanUpdateRequestBuilder