pub struct PaystackClient { /* private fields */ }
This is the struct that allows you to authenticate to the PayStack API. It contains the API key which allows you to interact with the API.

Implementations

source

impl PaystackClient

source

pub fn new<S: Into<String>>(key: S) -> Self

Create a new PayStack client with the specified API key.

It takes the following parameters: - key: Paystack API key.

source

pub async fn initialize_transaction( &self, transaction_body: TransactionBody ) -> PaystackResult<TransactionResponse>

Initalize a new transaction using the Paystack API.

The function takes a TransactionBody type as its parameter

source

pub async fn verify_transaction( &self, reference: String ) -> PaystackResult<TransactionStatus>

This function confirms the status of a transaction.

It takes the following parameters: - reference: The transaction reference used to intiate the transaction