pub struct TransactionBody {
    pub amount: String,
    pub email: String,
    pub currency: Option<String>,
    pub plan: Option<String>,
    pub transaction_charge: Option<i32>,
    pub bearer: Option<String>,
}
This struct is used to create a transaction body for creating a transaction using the Paystack API.

The struct has the following fields: - amount: Amount should be in the smallest unit of the currency e.g. kobo if in NGN and cents if in USD - email: Customer’s email address - currency (Optional): The transaction currency (NGN, GHS, ZAR or USD). Defaults to your integration currency. - plan (Optional): If transaction is to create a subscription to a predefined plan, provide plan code here. This would invalidate the value provided in amount - transaction_charge (Optional): An amount used to override the split configuration for a single split payment. If set, the amount specified goes to the main account regardless of the split configuration. - bearer (Optional): Who bears Paystack charges? account or subaccount (defaults to account).

Fields

amount: Stringemail: Stringcurrency: Option<String>plan: Option<String>transaction_charge: Option<i32>bearer: Option<String>