Plans Models
This file contains the models and options for the Plans endpoint of the Paystack API
Structs
- Plan
Request - Request body to create a plan on your integration.
Should be created via
PlanRequestBuilder - Plan
Request Builder - Builder for
PlanRequest. - Plan
Response Data - This struct represents the data of the create plan response.
- Plan
Update Request - Request body to update a plan on your integration.
Should be created via
PlanUpdateRequestBuilder - Plan
Update Request Builder - Builder for
PlanUpdateRequest.
Enums
- Interval
- Options for the different payment intervals for plans supported by the paystack API.
- Plan
Request Builder Error - Error type for PlanRequestBuilder
- Plan
Status - Plan
Update Request Builder Error - Error type for PlanUpdateRequestBuilder