Struct paystack::PaystackClient
source · pub struct PaystackClient { /* private fields */ }Expand description
This is the struct that allows you to authenticate to the PayStack API. It contains the API key which allows you to interact with the API.
Implementations
sourceimpl PaystackClient
impl PaystackClient
sourcepub fn new<S: Into<String>>(key: S) -> Self
pub fn new<S: Into<String>>(key: S) -> Self
Create a new PayStack client with the specified API key.
It takes the following parameters: - key: Paystack API key.
sourcepub async fn initialize_transaction(
&self,
transaction_body: TransactionBody
) -> PaystackResult<TransactionResponse>
pub async fn initialize_transaction( &self, transaction_body: TransactionBody ) -> PaystackResult<TransactionResponse>
Initalize a new transaction using the Paystack API.
The function takes a TransactionBody type as its parameter
sourcepub async fn verify_transaction(
&self,
reference: String
) -> PaystackResult<TransactionStatus>
pub async fn verify_transaction( &self, reference: String ) -> PaystackResult<TransactionStatus>
This function confirms the status of a transaction.
It takes the following parameters: - reference: The transaction reference used to intiate the transaction